#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dependent-map
version:              0.4.0.1
visibility:           public
id:                   dependent-map-0.4.0.1-1y9MDktF8dHRi3bcJk5BE
key:                  dependent-map-0.4.0.1-1y9MDktF8dHRi3bcJk5BE
license:              BSD-3-Clause
maintainer:           Obsidian Systems, LLC <maintainer@obsidian.systems>
author:               James Cook <mokus@deepbondi.net>
stability:            provisional
homepage:             https://github.com/obsidiansystems/dependent-map
synopsis:             Dependent finite maps (partial dependent products)
description:
    Provides a type called @DMap@ which generalizes
    @Data.Map.Map@, allowing keys to specify the type
    of value that can be associated with them.

category:             Data, Dependent Types
abi:                  858196cf364e57d8a455f5031266ece4
exposed:              True
exposed-modules:
    Data.Dependent.Map Data.Dependent.Map.Internal
    Data.Dependent.Map.Lens

hidden-modules:       Data.Dependent.Map.PtrEquality
import-dirs:          /usr/lib/ghc-9.6.6/site-local/dependent-map-0.4.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dependent-map-0.4.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dependent-map-0.4.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dependent-map
hs-libraries:         HSdependent-map-0.4.0.1-1y9MDktF8dHRi3bcJk5BE
depends:
    base-4.18.2.1 constraints-extras-0.4.0.2-IbE1vZKVCwe69iphe2pbeZ
    containers-0.6.7 dependent-sum-0.7.2.0-JmG9GyWCXDV8RvgongxwR8

haddock-interfaces:
    /usr/share/doc/haskell-dependent-map/html/dependent-map.haddock

haddock-html:         /usr/share/doc/haskell-dependent-map/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

